<?php

namespace Drupal\paragraphs_revisions_delete\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Paragraphs revisions delete settings.
 */
class ParagraphsRevisionsDeleteSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'paragraphs_revisions_delete.settings';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'paragraphs_revisions_delete_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(
    array              $form,
    FormStateInterface $form_state
  ): array {

    // Get the config for this form.
    $config = $this->config(static::SETTINGS);

    // The number of months form element.
    $form['number_of_months'] = [
      '#type' => 'number',
      '#title' => $this->t('Number of months'),
      '#description' => $this->t('Delete paragraph revisions older than this number of months.'),
      '#min' => 1,
      '#default_value' => $config->get('number_of_months') ?? 1,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(
    array &$form,
    FormStateInterface $form_state
  ): void {

    // Get the values from the form state.
    $values = $form_state->getValues();

    // Save the values in the config.
    $this->config(static::SETTINGS)
      ->set('number_of_months', $values['number_of_months'])
      ->save();
  }

}

